@@ -131,6 +131,18 @@ class s2py():
         requests.put("https://scratch.mit.edu/site-api/users/curators-in/" +
                      str(sid) + "/invite_curator/?usernames=" + user, headers=self.headers,)
 
+    def shareProject(self, pid):
+        self.headers["referer"] = (
+            "https://scratch.mit.edu/projects/"+str(pid)
+        )
+        return requests.put("https://api.scratch.mit.edu/proxy/projects/"+str(pid)+"/share",headers=self.headers)
+    
+    def unshareProject(self, pid):
+        self.headers["referer"] = (
+            "https://scratch.mit.edu/projects/"+str(pid)
+        )
+        return requests.put("https://api.scratch.mit.edu/proxy/projects/"+str(pid)+"/unshare",headers=self.headers)
+    
     def postStudioComment(self, sid, content, parent_id="", commentee_id=""):
         self.headers['referer'] = (
             "https://scratch.mit.edu/studios/" + str(sid) + "/comments/"
